@@ -6,14 +6,13 @@ import attr
 import numpy
 from rio_toa import toa_utils
 
-from rio_tiler.errors import InvalidBandName
+from rio_tiler.errors import InvalidBandName, MissingBands
 from rio_tiler.expression import apply_expression
-from rio_tiler.io import BaseReader, COGReader
+from rio_tiler.io import BaseReader, COGReader, MultiBandReader
 from rio_tiler.tasks import multi_arrays, multi_values
 from rio_tiler.utils import pansharpening_brovey
 
-from ...errors import MissingBands
-from ...reader import MultiBandReader, get_object
+from ... import get_object
 from ..utils import dn_to_toa, sceneid_parser
 
 landsat8_valid_bands = (
@@ -65,8 +64,8 @@ class L8Reader(MultiBandReader):
     _hostname: str = "landsat-pds"
     _prefix: str = "c1/L8/{path}/{row}/{scene}"
 
-    def __enter__(self):
-        """Support using with Context Managers."""
+    def __attrs_post_init__(self):
+        """Fetch MTL metadata and get bounds."""
         self.scene_params = sceneid_parser(self.sceneid)
         prefix = self._prefix.format(**self.scene_params)
         basename = f"{self.sceneid}_MTL.txt"
@@ -78,8 +77,15 @@ class L8Reader(MultiBandReader):
                 self.mtl_metadata["L1_METADATA_FILE"]["PRODUCT_METADATA"]
             )
         )
+
+    def __enter__(self):
+        """Support using with Context Managers."""
         return self
 
+    def __exit__(self, exc_type, exc_value, traceback):
+        """Support using with Context Managers."""
+        pass
+
     def _get_band_url(self, band: str) -> str:
         """Validate band name and return band's url."""
         if band not in self.bands:
