@@ -7,9 +7,9 @@ import attr
 from rasterio.features import bounds as featureBounds
 
 from rio_tiler.errors import InvalidBandName
-from rio_tiler.io import BaseReader
+from rio_tiler.io import BaseReader, GCPCOGReader, MultiBandReader
 
-from ...reader import GCPCOGReader, MultiBandReader, get_object
+from ... import get_object
 from ..utils import s1_sceneid_parser
 
 
@@ -35,7 +35,7 @@ class S1L1CReader(MultiBandReader):
 
     sceneid: str = attr.ib()
     reader: Type[BaseReader] = attr.ib(default=GCPCOGReader)
-    reader_options: Dict = attr.ib(factory=dict)
+    reader_options: Dict = attr.ib(default={"nodata": 0})
     minzoom: int = attr.ib(init=False, default=8)
     maxzoom: int = attr.ib(init=False, default=14)
 
@@ -47,8 +47,8 @@ class S1L1CReader(MultiBandReader):
     _hostname: str = "sentinel-s1-l1c"
     _prefix: str = "{product}/{acquisitionYear}/{_month}/{_day}/{beam}/{polarisation}/{scene}"
 
-    def __enter__(self):
-        """Support using with Context Managers."""
+    def __attrs_post_init__(self):
+        """Fetch productInfo and get bounds."""
         self.scene_params = s1_sceneid_parser(self.sceneid)
 
         prefix = self._prefix.format(**self.scene_params)
@@ -57,8 +57,15 @@ class S1L1CReader(MultiBandReader):
         )
         self.datageom = self.productInfo["footprint"]
         self.bounds = featureBounds(self.datageom)
+
+    def __enter__(self):
+        """Support using with Context Managers."""
         return self
 
+    def __exit__(self, exc_type, exc_value, traceback):
+        """Support using with Context Managers."""
+        pass
+
     def _get_band_url(self, band: str) -> str:
         """Validate band name and return band's url."""
         if band not in self.bands:
